==> mkdocstrings-python-legacy-0.1.0.tar.gz: mkdocstrings-python-legacy-0.1.0/README.md <==
# mkdocstrings-python (legacy)

[![ci](https://github.com/mkdocstrings/python-legacy/workflows/ci/badge.svg)](https://github.com/mkdocstrings/python-legacy/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://mkdocstrings.github.io/python-legacy/)
[![pypi version](https://img.shields.io/pypi/v/mkdocstrings-python-legacy.svg)](https://pypi.org/project/mkdocstrings-python-legacy/)
[![gitpod](https://img.shields.io/badge/gitpod-workspace-blue.svg?style=flat)](https://gitpod.io/#https://github.com/mkdocstrings/python-legacy)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://gitter.im/mkdocstrings/community)

A legacy Python handler for mkdocstrings.

## Requirements

mkdocstrings-python (legacy) requires Python 3.6 or above.

<details>
<summary>To install Python 3.6, I recommend using <a href="https://github.com/pyenv/pyenv"><code>pyenv</code></a>.</summary>

```bash
# install pyenv
git clone https://github.com/pyenv/pyenv ~/.pyenv

# setup pyenv (you should also put these three lines in .bashrc or similar)
export PATH="${HOME}/.pyenv/bin:${PATH}"
export PYENV_ROOT="${HOME}/.pyenv"
eval "$(pyenv init -)"

# install Python 3.6
pyenv install 3.6.12

# make it available globally
pyenv global system 3.6.12
```
</details>

## Installation

With `pip`:
```bash
python3.6 -m pip install mkdocstrings-python-legacy
```

With [`pipx`](https://github.com/pipxproject/pipx):
```bash
python3.6 -m pip install --user pipx

pipx install --python python3.6 mkdocstrings-python-legacy
```

==> mkdocstrings-python-legacy-0.2.0.tar.gz: mkdocstrings-python-legacy-0.2.0/README.md <==
# mkdocstrings-python (legacy)

[![ci](https://github.com/mkdocstrings/python-legacy/workflows/ci/badge.svg)](https://github.com/mkdocstrings/python-legacy/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://mkdocstrings.github.io/python-legacy/)
[![pypi version](https://img.shields.io/pypi/v/mkdocstrings-python-legacy.svg)](https://pypi.org/project/mkdocstrings-python-legacy/)
[![gitpod](https://img.shields.io/badge/gitpod-workspace-blue.svg?style=flat)](https://gitpod.io/#https://github.com/mkdocstrings/python-legacy)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://gitter.im/mkdocstrings/community)

A legacy Python handler for mkdocstrings.

## Requirements

mkdocstrings-python (legacy) requires Python 3.7 or above.

<details>
<summary>To install Python 3.7, I recommend using <a href="https://github.com/pyenv/pyenv"><code>pyenv</code></a>.</summary>

```bash
# install pyenv
git clone https://github.com/pyenv/pyenv ~/.pyenv

# setup pyenv (you should also put these three lines in .bashrc or similar)
export PATH="${HOME}/.pyenv/bin:${PATH}"
export PYENV_ROOT="${HOME}/.pyenv"
eval "$(pyenv init -)"

# install Python 3.7
pyenv install 3.7.12

# make it available globally
pyenv global system 3.7.12
```
</details>

## Installation

With `pip`:
```bash
pip install mkdocstrings-python-legacy
```

With [`pipx`](https://github.com/pipxproject/pipx):
```bash
python3.7 -m pip install --user pipx
pipx install mkdocstrings-python-legacy
```
